%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Parameters for the 'SFP communication with an RTDS MMC simulator' system
% Copyright imperix ltd, 2024
% dev@imperix.ch
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc; close all;

%% Communication parameters :
scale_factor = 0.5^16;          % From fixed-point 32.0 to fixed-point 16.16

%% Bus-side parameters :
Vdc = 100;                      % Bus EMF (V)

%% Three-phase-side parameters :
fg = 50;                        % Line frequency (Hz)

%% Submodules parameters :
N = 4;                          % Number of submodules per arm
Csm = 5e-3;                     % Submodule capacitance (F)
Rsm = 0;                        % Submodule capacitor ESR (ohm)

%% Branch parameters :
Rb = 50e-3;                     % Parasitic branch resistance (constant part, ohm)
Lb = 10e-3;                     % Branch indu ctance (self part, H)

%% Time parameters:
fs = 5e3;                       % Interrupt frequency [Hz]
Ts = 1/fs;                      % Interrupt period [s]
fsw = fs/N;                     % Switching frequency [Hz]
Tsw = 1/fsw;                    % Switching period [s]
Td = 1.5*Ts + 0.5*Tsw;          % Control delay [s]

%% Partial bus currents regulators
L = 2*Lb;
R = 2*Rb;
K1 = 1/R;
T1 = L/R;
Tn = T1;
Ti = 2*K1*Td;
Kp_Ibus = Tn/Ti;
Ki_Ibus = 1/Ti;

%% Submodules voltage regulators
C = Csm;
T2 = C;
Tdeq = 2*Td;
a = 6;
Tn = a^2*Tdeq;
Ti = a^3*Tdeq^2/T2;
Kp_Vsm  = Tn/Ti;
Ki_Vsm = 1/Ti;

%% Leg voltages regulators
C = Csm/N;
T2 = C;
Tdeq = 2*Td;
a = 6;
Tn = a^2*Tdeq;
Ti = a^3*Tdeq^2/T2;
Kp_Vleg  = Tn/Ti;
Ki_Vleg = 1/Ti;

%% Protection of Vsm
Vsm_max = 250;